-----------------------------------------------------------------------
-- Locale
-----------------------------------------------------------------------
local L = AceLibrary("AceLocale-2.2"):new("Violation: PlayerDPS")

L:RegisterTranslations("enUS", function() return {
	["Damage per Second"] = true,

	["DPS: "] = true,

	["DPS"] = true,
	["Player"] = true,
	["#"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Damage per Second"] = "초당 피해량",

	["DPS: "] = "DPS: ",

	["DPS"] = "DPS",
	["Player"] = "플레이어",
	["#"] = "#",
} end)

-----------------------------------------------------------------------
-- Locals
-----------------------------------------------------------------------

local tablet = AceLibrary("Tablet-2.0")

local percentString = "(%d%%)"

local playerName = nil

local event = {
	eventType = "Damage",
	sourceID = "player",
}

local data = nil
local position = nil
local dirty = 0
local lastUpdateTime
local seconds = nil
local oldDPS = 0

-----------------------------------------------------------------------
-- Module declaration
-----------------------------------------------------------------------

local mod = Violation:NewModule("PlayerDPS", "Parser-3.0")
mod.revision = tonumber(("$Revision: 29160 $"):sub(12, -3)) or 1
mod.version = 2

-----------------------------------------------------------------------
-- Module initialization
-----------------------------------------------------------------------

function mod:OnModuleRegister()
	playerName = UnitName("player")
end

function mod:OnModuleEnable()
	self:RegisterParserEvent(event, "OnParserEvent")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
end

function mod:OnReset()
	if type(data) == "table" then
		data = self:del(data)
	end

	data = self:new()
	data[playerName] = 0
	seconds = 0
	oldDPS = 0
end

-----------------------------------------------------------------------
-- Module implementation
-----------------------------------------------------------------------

function mod:GetRevision() return self.revision end
function mod:GetDisplayName() return L["Damage per Second"] end
function mod:GetBroadcastData() return dirty end

function mod:IsDirty()
	return dirty ~= 0
end

function mod:OnRemoteData(sender, input)
	-- remote dps is placed in the damage table, this is done so we don't need to recalc everybody else's DPS.
	data[sender] = (data[sender] or 0) + input
end

function mod:PLAYER_REGEN_ENABLED()
	lastUpdateTime = nil
end

function mod:OnParserEvent(event)
	assert(event.sourceID == "player", "Not supposed to get combat events from people except ourselves.")
	if event.amount then
		local newTime = GetTime()
		local timeSinceLastUpdate
		-- on the offhand chance that lastUpdateTime is nil at this point (if somehow we do damage before a regen disabled event fires)
		-- make sure that we have a 
		if not lastUpdateTime then
			timeSinceLastUpdate = 0.1
		else
			timeSinceLastUpdate = newTime - lastUpdateTime
		end
		lastUpdateTime = newTime
		data[playerName] = data[playerName] + event.amount
		seconds = seconds + timeSinceLastUpdate
		local newDPS = data[playerName] / seconds
		dirty = newDPS - oldDPS
		oldDPS = newDPS
	end
end

function mod:GetData(player)
	if player then
		return data[player]
	else
		return data
	end
end

function mod:GetDisplayText()
	if data and data[playerName] > 0 then
		return L["DPS: "] .. (type(position) ~= "nil" and tostring(position) .. ". " or "") .. math.floor(data[playerName]/seconds)
	end
	return nil
end

